@@ -4,8 +4,9 @@ It contains functionality for creating, solving, and visualising the solution
 of Parmokinetic (PK) models
 
 """
-# # Import version info
-# __version__ = importlib.metadata.version(__name__)
 
-# # Import main classes
-# from .model import Model    # noqa
\ No newline at end of file
+# Import main classes
+from .model import Model
+from .input import *
+from .solver import *
+from .output import *
