@@ -1,4 +1,4 @@
-from .input import *
+from .input import central_input
 from .model import Model
 from .solver import *
 from .output import *
